@@ -40,6 +40,11 @@ pub struct CreateBookingIntendInput {
     pub interval: i64,
 }
 
+pub struct RemoveBookingIntendInput {
+    pub service_id: ID,
+    pub timestamp: i64,
+}
+
 pub struct RemoveServiceUserInput {
     pub service_id: ID,
     pub user_id: ID,
@@ -119,6 +124,21 @@ impl ServiceClient {
             .await
     }
 
+    pub async fn remove_booking_intend(
+        &self,
+        input: RemoveBookingIntendInput,
+    ) -> APIResponse<remove_service_event_intend::APIResponse> {
+        self.base
+            .delete(
+                format!(
+                    "service/{}/booking-intend?timestamp={}",
+                    input.service_id, input.timestamp
+                ),
+                StatusCode::OK,
+            )
+            .await
+    }
+
     pub async fn delete(&self, service_id: ID) -> APIResponse<delete_service::APIResponse> {
         self.base
             .delete(format!("service/{}", service_id), StatusCode::OK)
